@@ -57,7 +57,7 @@ class TestOptions(_IntegrationTest):
   """Test client options."""
 
   def test_timeout(self):
-    self.client._timeout = 1e-4 # Small enough for it to always timeout.
+    self.client._timeout = 1e-5 # Small enough for it to always timeout.
     try:
       self.client.status('.')
     except (ConnectTimeout, ReadTimeout):
@@ -93,7 +93,7 @@ class TestApi(_IntegrationTest):
     ok_(not self.client._delete(path).json()['boolean'])
 
   def test_rename_file(self):
-    paths = ['foo', '%s/bar' % (self.client.root.rstrip('/'), )]
+    paths = ['foo', '{}/bar'.format(self.client.root.rstrip('/'))]
     self._write(paths[0], b'hello')
     ok_(self.client._rename(paths[0], destination=paths[1]).json()['boolean'])
     ok_(not self._exists(paths[0]))
@@ -101,7 +101,7 @@ class TestApi(_IntegrationTest):
     self.client._delete(paths[1])
 
   def test_rename_file_to_existing(self):
-    p = ['foo', '%s/bar' % (self.client.root.rstrip('/'), )]
+    p = ['foo', '{}/bar'.format(self.client.root.rstrip('/'))]
     self._write(p[0], b'hello')
     self._write(p[1], b'hi')
     try:
@@ -124,111 +124,6 @@ class TestApi(_IntegrationTest):
   def test_get_file_checksum_on_folder(self):
     self.client._get_file_checksum('')
 
-  def test_allow_snapshot(self):
-    self.client._mkdirs('foo')
-    self.client._allow_snapshot('foo')
-
-  def test_disallow_snapshot(self):
-    self.client._mkdirs('foo')
-    self.client._allow_snapshot('foo')
-    self.client._disallow_snapshot('foo')
-
-  @raises(HdfsError)
-  def test_allow_snapshot_not_exists(self):
-    self.client._allow_snapshot('foo')
-
-  @raises(HdfsError)
-  def test_disallow_snapshot_not_exists(self):
-    self.client._disallow_snapshot('foo')
-
-  @raises(HdfsError)
-  def test_allow_snapshot_file(self):
-    self._write('foo', b'hello')
-    self.client._allow_snapshot('foo')
-
-  @raises(HdfsError)
-  def test_disallow_snapshot_file(self):
-    self._write('foo', b'hello')
-    self.client._disallow_snapshot('foo')
-
-  def test_create_delete_snapshot(self):
-    # One cannot test creation and deletion separately, as one cannot
-    # clean HDFS for test isolation if a created snapshot remains
-    # undeleted.
-    self.client._mkdirs('foo')
-    self.client._allow_snapshot('foo')
-    self.client._create_snapshot('foo', snapshotname='mysnap')
-    self.client._delete_snapshot('foo', snapshotname='mysnap')
-
-  @raises(HdfsError)
-  def test_delete_snapshot_other(self):
-    self.client._mkdirs('foo')
-    self.client._allow_snapshot('foo')
-    self.client._create_snapshot('foo', snapshotname='mysnap')
-    try:
-      self.client._delete_snapshot('foo', snapshotname='othersnap')
-    finally:
-      # Cleanup, as it breaks other tests otherwise: the dir cannot be
-      # removed with an active snapshots.
-      self.client._delete_snapshot('foo', snapshotname='mysnap')
-
-  @raises(HdfsError)
-  def test_disallow_snapshot_exists(self):
-    self.client._mkdirs('foo_disallow')
-    self.client._allow_snapshot('foo_disallow')
-    self.client._create_snapshot('foo_disallow', snapshotname='mysnap')
-    try:
-      self.client._disallow_snapshot('foo_disallow')
-    finally:
-      # Cleanup, as it breaks other tests otherwise: the dir cannot be
-      # removed with an active snapshots.
-      self.client._delete_snapshot('foo_disallow', snapshotname='mysnap')
-
-  @raises(HdfsError)
-  def test_create_snapshot_noallow(self):
-    self.client._mkdirs('foo')
-    self.client._create_snapshot('foo', snapshotname='mysnap')
-
-  @raises(HdfsError)
-  def test_delete_snapshot_noallow(self):
-    self.client._mkdirs('foo')
-    self.client._delete_snapshot('foo', snapshotname='mysnap')
-
-  @raises(HdfsError)
-  def test_create_snapshot_noexist(self):
-    self.client._create_snapshot('foo', snapshotname='mysnap')
-
-  def test_rename_snapshot(self):
-    self.client._mkdirs('foo')
-    self.client._allow_snapshot('foo')
-    self.client._create_snapshot('foo', snapshotname='myspan')
-    try:
-      self.client._rename_snapshot('foo',
-                                   oldsnapshotname='myspan',
-                                   snapshotname='yourspan')
-    finally:
-      self.client._delete_snapshot('foo', snapshotname='yourspan')
-
-  @raises(HdfsError)
-  def test_rename_snapshot_not_exists(self):
-    self.client._rename_snapshot('foo',
-                                 oldsnapshotname='myspan',
-                                 snapshotname='yourspan')
-
-  @raises(HdfsError)
-  def test_rename_snapshot_not_overwrite(self):
-    self.client._mkdirs('foo')
-    self.client._allow_snapshot('foo')
-    self.client._create_snapshot('foo', snapshotname='myspan')
-    self.client._create_snapshot('foo', snapshotname='yourspan')
-    try:
-      self.client._rename_snapshot('foo',
-                                   oldsnapshotname='myspan',
-                                   snapshotname='yourspan')
-    finally:
-      self.client._delete_snapshot('foo', snapshotname='myspan')
-      self.client._delete_snapshot('foo', snapshotname='yourspan')
-
 
 class TestResolve(_IntegrationTest):
 
@@ -769,7 +664,7 @@ class TestDownload(_IntegrationTest):
       'part-r-00002': b'foo',
     }
     for name, content in parts.items():
-      self._write('dl/%s' % (name, ), content)
+      self._write('dl/{}'.format(name), content)
     with temppath() as tpath:
       self.client.download('dl', tpath, n_threads=-1)
       local_parts = os.listdir(tpath)
@@ -1066,6 +961,27 @@ class TestAcl(_IntegrationTest):
   def test_missing_non_strict(self):
     ok_(self.client.acl_status('foo', strict=False) is None)
 
+  def test_remove_acl_entries(self):
+    self.client.write('foo', 'hello, world!')
+    self.client.set_acl('foo', 'user:baruser:rwx,user:foouser:rw-', clear=False)
+    self.client.remove_acl_entries('foo', 'user:foouser:')
+    content = self.client.acl_status('foo')
+    ok_(not any('user:foouser:rw-' in s for s in content['entries']))
+    ok_(any('user:baruser:rwx' in s for s in content['entries']))
+
+  def test_remove_default_acl(self):
+    self.client.write('foo', 'hello, world!')
+    self.client.set_acl('foo', 'user:foouser:rwx', clear=False)
+    self.client.remove_default_acl('foo')
+    content = self.client.acl_status('foo')
+    ok_(not any('user::rwx' in s for s in content['entries']))
+
+  def test_remove_acl(self):
+    self.client.write('foo', 'hello, world!')
+    self.client.remove_acl('foo')
+    content = self.client.acl_status('foo')
+    eq_(content.get('entries'), [])
+
 
 class TestList(_IntegrationTest):
 
@@ -1346,7 +1262,7 @@ class TestChecksum(_IntegrationTest):
   def test_file(self):
     self.client.write('foo', 'hello')
     checksum = self.client.checksum('foo')
-    eq_(set(['algorithm', 'bytes', 'length']), set(checksum))
+    eq_({'algorithm', 'bytes', 'length'}, set(checksum))
 
 
 class TestSetReplication(_IntegrationTest):
@@ -1386,6 +1302,21 @@ class TestTokenClient(object):
 
 class TestSnapshot(_IntegrationTest):
 
+  @classmethod
+  def setup_class(cls):
+    super(TestSnapshot, cls).setup_class()
+    if cls.client:
+      cls.client._mkdirs('foo')
+      try:
+        cls.client.allow_snapshot('foo')
+      except HdfsError as err:
+        if 'java.lang.IllegalArgumentException: No enum constant' in str(err):
+          cls.client = None
+          # Skip these tests if we get this error message from HDFS (currently
+          # happens using HTTPFS) which causes all snapshot operations to fail.
+        else:
+          raise err
+
   def test_allow_snapshot(self):
     self.client._mkdirs('foo')
     self.client.allow_snapshot('foo')
@@ -1393,6 +1324,7 @@ class TestSnapshot(_IntegrationTest):
   def test_allow_snapshot_double(self):
     self.client._mkdirs('foo')
     self.client.allow_snapshot('foo')
+    self.client.allow_snapshot('foo')
 
   def test_disallow_snapshot(self):
     self.client._mkdirs('foo')
